@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004, 2005 Jorn Baayen <jbaayen@gnome.org>
+ * Copyright (C) 2004, 2005 Jorn Baayen <jorn.baayen@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 using System;
@@ -32,12 +32,12 @@ namespace Muine
 		// Strings
 		// Strings :: Prefixes
 		/// <summary>
-		///	Space-separated list of prefixes that will be taken off the front
-		///	when sorting.
+		/// Space-separated list of prefixes that will be taken off the front
+		/// when sorting.
 		/// </summary>
 		/// <remarks>
 		///	For example, "The Beatles" will be sorted as "Beatles",
-		///	if "the" is included in this list. Also include the English "the"
+		/// if "the" is included in this list. Also include the English "the"
 		///	if English is generally spoken in your country.
 		/// </summary>
 		private static readonly string string_prefixes = 
@@ -212,7 +212,12 @@ namespace Muine
 		///	True if album is complete, False otherwise.
 		/// </returns>
 		public override bool Public {
-			get { return complete; }
+			get {
+				if (Global.DB.OnlyCompleteAlbums)
+					return complete;
+				else
+					return true;
+			}
 		}
 
 		// Properties :: Key (get;)
@@ -427,13 +432,19 @@ namespace Muine
 			string [] p_artists = new string [artists.Count];
 
 			for (int i = 0; i < artists.Count; i ++) {
-				p_artists [i] = ((string) artists [i]).ToLower ();
+				string artist_tmp = (string) artists [i];
+				string artist = artist_tmp.ToLower ();
+
+				p_artists [i] = artist;
 				
 				foreach (string prefix in prefixes) {
-					if (!p_artists [i].StartsWith (prefix + " "))
+					bool has_prefix = artist.StartsWith (prefix + " ");
+					if (!has_prefix)
 						continue;
 
-					p_artists [i] = StringUtils.PrefixToSuffix (p_artists [i], prefix);
+					p_artists [i] =
+					  StringUtils.PrefixToSuffix (artist, prefix);
+
 					break;
 				}
 			}
@@ -444,13 +455,19 @@ namespace Muine
 			string [] p_performers = new string [performers.Count];
 
 			for (int i = 0; i < performers.Count; i ++) {
-				p_performers [i] = ((string) performers [i]).ToLower ();
-				
+				string performer_tmp = (string) performers [i];
+				string performer = performer_tmp.ToLower ();
+
+				p_performers [i] = performer;				
+			
 				foreach (string prefix in prefixes) {
-					if (!p_performers [i].StartsWith (prefix + " "))
+					bool has_prefix = performer.StartsWith (prefix + " ");
+					if (!has_prefix)
 						continue;
 
-					p_performers [i] = StringUtils.PrefixToSuffix (p_performers [i], prefix);
+					p_performers [i] =
+					  StringUtils.PrefixToSuffix (performer, prefix);
+
 					break;
 				}
 			}
@@ -465,8 +482,8 @@ namespace Muine
 			else
 				key = String.Format ("{0} {1} {2} {3}", a, p, year, name);
 
-			return CultureInfo.CurrentUICulture.CompareInfo.GetSortKey (key, 
-				CompareOptions.IgnoreCase);
+			return CultureInfo.CurrentUICulture.CompareInfo.GetSortKey
+			  (key, CompareOptions.IgnoreCase);
 		}
 
 		// Methods :: Protected :: GenerateSearchKey (Item)
